All Classes and Interfaces
Class
Description
Service client for accessing AWS AppConfig Data asynchronously.
A builder for creating an instance of
AppConfigDataAsyncClient.The parameters object used to resolve the auth schemes for the AppConfigData service.
A builder for a
AppConfigDataAuthSchemeParams.An auth scheme provider for AppConfigData service.
This includes configuration specific to AWS AppConfig Data that is supported by both
AppConfigDataClientBuilder and AppConfigDataAsyncClientBuilder.Service client for accessing AWS AppConfig Data.
A builder for creating an instance of
AppConfigDataClient.The parameters object used to resolve an endpoint for the AppConfigData service.
An endpoint provider for AppConfigData.
Class to expose the service client settings to the user.
A builder for creating a
AppConfigDataServiceClientConfigurationAn AWS Arn.
Detailed information about the input that failed to satisfy the constraints specified by a call.
The input fails to satisfy the constraints specified by the service.
Link between an endpoint property and the
AwsEndpointAttribute it represents.GetLatestConfigurationRequest MarshallerIdentifiers for variables declared within the rule engine, e.g.
There was an internal failure in the service.
Information about an invalid parameter.
The requested resource could not be found.
Represents a URL to be used internally for endpoint resolution.
StartConfigurationSessionRequest Marshaller
The request was denied due to request throttling.
Base class for the types of values computable by the
RuleEngine.An array value.
A boolean value.
An integer value.
A record (map) value.
A string value.